@@ -215,6 +215,9 @@ def show(items):
             db_table.add_row([colored("HistoryMaxSize", "magenta"), db.HistoryMaxSize])
             db_table.add_row([colored("Description", "magenta"), db.Description])
             db_table.add_row([colored("MaintenanceHistoryDays", "magenta"), db.MaintenanceHistoryDays])
+            db_table.add_row([colored("Filename", "magenta"), ctx.keepass.file_name])
+            if ctx.keepass.db_type == "PassXYZ":
+                db_table.add_row([colored("Decoded Filename", "magenta"), ctx.keepass.user_name])
             cprint("Database configureation", "yellow")
             print(db_table)
         else:
@@ -222,6 +225,7 @@ def show(items):
     elif items == "version":
         version()
     elif items == "databases":
+        print("The current path: ", get_homepath())
         db_table = PrettyTable(["No.", "Name"])
         db_table.align = "l"
         num = 1
@@ -253,9 +257,12 @@ def open(dbfile: str, password = ""):
         cprint("Database name: {}\nDescription: {}\nMaintenanceHistoryDays:{}"
             .format(db.Name, db.Description, db.MaintenanceHistoryDays))
     else:
-        logger = KPCLibPyLogger()
-        db_path = get_homepath() + '/' + dbfile
-        ctx.keepass.open(db_path, password, logger)
+        #logger = KPCLibPyLogger()
+        #db_path = get_homepath() + '/' + dbfile
+        #ctx.keepass.open(db_path, password, logger)
+        ctx.keepass.connect(dbfile, password)
+    
+    ctx.keepass.file_name = dbfile
 
 
 @command
